@@ -12,6 +12,7 @@ from motorengine.aggregation.base import Aggregation
 from motorengine.connection import get_connection
 from motorengine.errors import UniqueKeyViolationError
 
+DEFAULT_LIMIT = 1000
 
 class QuerySet(object):
     def __init__(self, klass):
@@ -50,7 +51,7 @@ class QuerySet(object):
                 name = StringField()
 
             io_loop = tornado.ioloop.IOLoop.instance()
-            connect("test", host="localhost", port=4445, io_loop=io_loop)
+            connect("test", host="localhost", port=27017, io_loop=io_loop)
 
         .. testcode:: saving_create
 
@@ -73,7 +74,7 @@ class QuerySet(object):
         def handle(*arguments, **kw):
             if len(arguments) > 1 and arguments[1]:
                 if isinstance(arguments[1], (DuplicateKeyError, )):
-                    raise UniqueKeyViolationError.from_pymongo(arguments[1].message, self.__klass__)
+                    raise UniqueKeyViolationError.from_pymongo(str(arguments[1]), self.__klass__)
                 else:
                     raise arguments[1]
 
@@ -220,7 +221,7 @@ class QuerySet(object):
                 name = StringField()
 
             io_loop = tornado.ioloop.IOLoop.instance()
-            connect("test", host="localhost", port=4445, io_loop=io_loop)
+            connect("test", host="localhost", port=27017, io_loop=io_loop)
 
         .. testcode:: saving_delete
 
@@ -488,6 +489,8 @@ class QuerySet(object):
 
         if self._limit is not None:
             to_list_arguments['length'] = self._limit
+        else:
+            to_list_arguments['length'] = DEFAULT_LIMIT
 
         cursor = self._get_find_cursor(alias=alias)
 
